@@ -10,8 +10,10 @@ import publication
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_cloudfront._jsii
+import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import aws_solutions_constructs.aws_cloudfront_apigateway._jsii
 import aws_solutions_constructs.core._jsii
@@ -19,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cloudfront-apigateway-lambda",
-    "1.50.0",
+    "1.57.0",
     __name__[0:-6],
-    "aws-cloudfront-apigateway-lambda@1.50.0.jsii.tgz",
+    "aws-cloudfront-apigateway-lambda@1.57.0.jsii.tgz",
 )
 
 __all__ = [
